<?php namespace Concrete\Package\EzRecipe\Block\EzRecipe;
use \Concrete\Core\Block\BlockController;
use File;
use Core;

class Controller extends BlockController
{
    protected $btTable = 'btEzRecipe';
    protected $btInterfaceWidth = "640";
    protected $btWrapperClass = 'ccm-ui';
    protected $btInterfaceHeight = "500";

    public function getBlockTypeDescription() {
        return t("Easily add a recipe block to any page.");
    }

    public function getBlockTypeName() {
        return t("EZ Recipe");
    }

	public function add() {
        $this->edit();
    }
	public function edit() {
		$this->requireAsset('redactor');
		$this->requireAsset('core/sitemap');
		$this->requireAsset('core/file-manager');
	}

	public function getFileID() {
        return $this->fID;
    }
	public function getFileObject() {
        return File::getByID($this->fID);
    }
	public function validate($args) {
        $e = Core::make("helper/validation/error");       
		if(empty($args['recipeTitle'])){
            $e->add(t("Recipe Title is required."));
        }
		if(strlen($args['recipeTitle']) > 255) {
			$e->add(t("Recipe Title cannot exceed 255 characters."));
		}
		if(empty($args['recipeDesc'])){
            $e->add(t("Recipe Description is required."));
        }
		if(empty($args['ingredients'])){
            $e->add(t("Ingredients are needed!"));
        }
		if(empty($args['steps'])){
            $e->add(t("Instructions are needed!"));
        }
		if(empty($args['serves'])){
            $e->add(t("Servings are required!"));
        }
		if(strlen($args['serves']) > 100) {
			$e->add(t("Servings cannot exceed 100 characters."));
		}
		if(empty($args['prepTime'])){
            $e->add(t("Prep Time is required!"));
        }
		if(strlen($args['prepTime']) > 100) {
			$e->add(t("Prep Time cannot exceed 100 characters."));
		}
		
		if(!ctype_digit(trim($args['calories']))){
            $e->add(t("Calories must be numeric only."));
        }
		if(!ctype_digit(trim($args['carbs']))){
            $e->add(t("Carbs must be numeric only."));
        }
		if(!ctype_digit(trim($args['fiber']))){
            $e->add(t("Fiber must be numeric only."));
        }
		if(!ctype_digit(trim($args['fat']))){
            $e->add(t("Fat must be numeric only."));
        }
		if(!ctype_digit(trim($args['protein']))){
            $e->add(t("Protein must be numeric only."));
        }
		if(!ctype_digit(trim($args['sodium']))){
            $e->add(t("Sodium must be numeric only."));
        }
		
		if(empty($args['fID'])){
            $e->add(t("Cover Image is required."));
        } elseif (!empty($args['fID'])) {
			$f = File::getByID($args['fID']); // Get the file	
			$fv = $f->getVersion();  // Get the file version
			$fileType = $fv->getExtension();  // Get the file extension
			$ftypes = array("jpg", "JPG", "jpeg", "png", "PNG"); // Define array of file types.
			if(!in_array($fileType, $ftypes)) {   // If the file extension is NOT in the array, return this error.
				$e->add(t("Invalid background image type. Please select either a PNG or JPG file."));
			}
		}
        return $e;
    }
	
	public function save($args) {
		$args['evHeight'] 	= is_numeric($args['evHeight']) ? intval($args['evHeight']) : '200';
		parent::save($args);
	}

}
